import { defineStore } from 'pinia';
import {
	fetchAddDebtCollectionManagement,
	fetchDeleteDebtCollectionManagement,
	fetchGetDebtCollectionManagementList,
	fetchUpdateDebtCollectionManagement,
} from '@/api/v1/financial/debtCollectionManagement';
import { pageSizes } from '@/enums/baseConstant';
import { storeMessage } from '@/utils/message';
import { storePagination } from '@/store/useStorePagination';

/**
 * 债务回收管理表 Store
 */
export const useDebtCollectionManagementStore = defineStore('debtCollectionManagementStore', {
	state() {
		return {
			// 债务回收管理表列表
			datalist: [],
			// 查询表单
			form: {
				// 债务ID
				debtId: undefined,
				// 回收日期
				recoveryDate: undefined,
				// 回收金额
				recoveryAmount: undefined,
				// 回收方式
				recoveryMethod: undefined,
				// 备注
				notes: undefined,
			},
			// 分页查询结果
			pagination: {
				currentPage: 1,
				pageSize: 30,
				total: 1,
				pageSizes,
			},
			// 加载
			loading: false,
		};
	},
	getters: {},
	actions: {
		/** 获取债务回收管理表 */
		async getDebtCollectionManagementList() {
			// 整理请求参数
			const data = { ...this.pagination, ...this.form };
			delete data.pageSizes;
			delete data.total;
			delete data.background;

			// 获取债务回收管理表列表
			const result = await fetchGetDebtCollectionManagementList(data);

			// 公共页面函数hook
			const pagination = storePagination.bind(this);
			return pagination(result);
		},

		/** 添加债务回收管理表 */
		async addDebtCollectionManagement(data: any) {
			const result = await fetchAddDebtCollectionManagement(data);
			return storeMessage(result);
		},

		/** 修改债务回收管理表 */
		async updateDebtCollectionManagement(data: any) {
			const result = await fetchUpdateDebtCollectionManagement(data);
			return storeMessage(result);
		},

		/** 删除债务回收管理表 */
		async deleteDebtCollectionManagement(data: any) {
			const result = await fetchDeleteDebtCollectionManagement(data);
			return storeMessage(result);
		},
	},
});
