import { reactive } from 'vue';
import { $t } from '@/plugins/i18n';
import type { FormRules } from 'element-plus';

// 表格列
export const columns: TableColumnList = [
	{ type: 'selection', align: 'left' },
	{ type: 'index', index: (index: number) => index + 1, label: '序号', width: 60 },
	// 债务ID
	{ label: $t('debtId'), prop: 'debtId' },
	// 回收日期
	{ label: $t('recoveryDate'), prop: 'recoveryDate' },
	// 回收金额
	{ label: $t('recoveryAmount'), prop: 'recoveryAmount' },
	// 回收方式
	{ label: $t('recoveryMethod'), prop: 'recoveryMethod' },
	// 备注
	{ label: $t('notes'), prop: 'notes' },
	{ label: $t('table.updateTime'), prop: 'updateTime', sortable: true, width: 160 },
	{ label: $t('table.createTime'), prop: 'createTime', sortable: true, width: 160 },
	{ label: $t('table.operation'), fixed: 'right', width: 210, slot: 'operation' },
];

// 添加规则
export const rules = reactive<FormRules>({
	// 债务ID
	debtId: [{ required: true, message: `${$t('input')}${$t('debtId')}`, trigger: 'blur' }],
	// 回收日期
	recoveryDate: [{ required: true, message: `${$t('input')}${$t('recoveryDate')}`, trigger: 'blur' }],
	// 回收金额
	recoveryAmount: [{ required: true, message: `${$t('input')}${$t('recoveryAmount')}`, trigger: 'blur' }],
	// 回收方式
	recoveryMethod: [{ required: true, message: `${$t('input')}${$t('recoveryMethod')}`, trigger: 'blur' }],
	// 备注
	notes: [{ required: true, message: `${$t('input')}${$t('notes')}`, trigger: 'blur' }],
});
