import { addDialog } from '@/components/BaseDialog/index';
import DebtCollectionManagementDialog from '@/views/financial/debtCollectionManagement/debt-collection-management-dialog.vue';
import { useDebtCollectionManagementStore } from '@/store/financial/debtCollectionManagement';
import { h, ref } from 'vue';
import { message, messageBox } from '@/utils/message';
import type { FormItemProps } from '@/views/financial/debtCollectionManagement/utils/types';
import { $t } from '@/plugins/i18n';
import DeleteBatchDialog from '@/components/Table/DeleteBatchDialog.vue';

export const formRef = ref();
// 删除ids
export const deleteIds = ref([]);
const debtCollectionManagementStore = useDebtCollectionManagementStore();

/** 搜索初始化债务回收管理表 */
export async function onSearch() {
	debtCollectionManagementStore.loading = true;
	await debtCollectionManagementStore.getDebtCollectionManagementList();
	debtCollectionManagementStore.loading = false;
}

/** 添加债务回收管理表 */
export function onAdd() {
	addDialog({
		title: `${$t('addNew')}${$t('debtCollectionManagement')}`,
		width: '30%',
		props: {
			formInline: {
				debtId: undefined,
				recoveryDate: undefined,
				recoveryAmount: undefined,
				recoveryMethod: undefined,
				notes: undefined,
			},
		},
		draggable: true,
		fullscreenIcon: true,
		closeOnClickModal: false,
		contentRenderer: () => h(DebtCollectionManagementDialog, { ref: formRef }),
		beforeSure: (done, { options }) => {
			const form = options.props.formInline as FormItemProps;
			formRef.value.formRef.validate(async (valid: any) => {
				if (!valid) return;

				const result = await debtCollectionManagementStore.addDebtCollectionManagement(form);
				if (!result) return;
				done();
				await onSearch();
			});
		},
	});
}

/** 更新债务回收管理表 */
export function onUpdate(row: any) {
	addDialog({
		title: `${$t('modify')}${$t('debtCollectionManagement')}`,
		width: '30%',
		props: {
			formInline: {
				debtId: row.debtId,
				recoveryDate: row.recoveryDate,
				recoveryAmount: row.recoveryAmount,
				recoveryMethod: row.recoveryMethod,
				notes: row.notes,
			},
		},
		draggable: true,
		fullscreenIcon: true,
		closeOnClickModal: false,
		contentRenderer: () => h(DebtCollectionManagementDialog, { ref: formRef }),
		beforeSure: (done, { options }) => {
			const form = options.props.formInline as FormItemProps;
			formRef.value.formRef.validate(async (valid: any) => {
				if (!valid) return;

				const result = await debtCollectionManagementStore.updateDebtCollectionManagement({ ...form, id: row.id });
				if (!result) return;
				done();
				await onSearch();
			});
		},
	});
}

/** 删除债务回收管理表 */
export const onDelete = async (row: any) => {
	const id = row.id;

	// 是否确认删除
	const result = await messageBox({
		title: $t('confirmDelete'),
		showMessage: false,
		confirmMessage: undefined,
		cancelMessage: $t('cancel_delete'),
	});
	if (!result) return;

	// 删除数据
	await debtCollectionManagementStore.deleteDebtCollectionManagement([id]);
	await onSearch();
};

/** 批量删除 */
export const onDeleteBatch = async () => {
	const ids = deleteIds.value;
	const formDeletedBatchRef = ref();

	addDialog({
		title: $t('deleteBatchTip'),
		width: '30%',
		props: { formInline: { confirmText: '' } },
		draggable: true,
		fullscreenIcon: true,
		closeOnClickModal: false,
		contentRenderer: () => h(DeleteBatchDialog, { ref: formDeletedBatchRef }),
		beforeSure: (done, { options }) => {
			formDeletedBatchRef.value.formDeletedBatchRef.validate(async (valid: any) => {
				if (!valid) return;

				const text = options.props.formInline.confirmText.toLowerCase();
				if (text === 'yes' || text === 'y') {
					// 删除数据
					await debtCollectionManagementStore.deleteDebtCollectionManagement(ids);
					await onSearch();

					done();
				} else message($t('deleteBatchTip'), { type: 'warning' });
			});
		},
	});
};
